@@ -16,6 +16,7 @@ from ..services.webhook import WebhookService
 from ..services.vendor_assistant import VendorAssistantService
 from ..services.vendor_workflow import VendorWorkflowService
 from ..services.vendor_knowledgebase import VendorKnowledgeBaseService
+from ..services.vendor_guardrail import VendorGuardrailService
 
 
 class CodeMieClient:
@@ -101,6 +102,9 @@ class CodeMieClient:
         self.vendor_knowledgebases = VendorKnowledgeBaseService(
             self._api_domain, self._token, verify_ssl=self._verify_ssl
         )
+        self.vendor_guardrails = VendorGuardrailService(
+            self._api_domain, self._token, verify_ssl=self._verify_ssl
+        )
 
     @property
     def token(self) -> str:
@@ -147,6 +151,12 @@ class CodeMieClient:
         self.conversations = ConversationService(
             self._api_domain, self._token, verify_ssl=self._verify_ssl
         )
+        self.files = FileOperationService(
+            self._api_domain, self._token, verify_ssl=self._verify_ssl
+        )
+        self.webhook = WebhookService(
+            self._api_domain, self._token, verify_ssl=self._verify_ssl
+        )
         self.vendor_assistants = VendorAssistantService(
             self._api_domain, self._token, verify_ssl=self._verify_ssl
         )
@@ -156,4 +166,7 @@ class CodeMieClient:
         self.vendor_knowledgebases = VendorKnowledgeBaseService(
             self._api_domain, self._token, verify_ssl=self._verify_ssl
         )
+        self.vendor_guardrails = VendorGuardrailService(
+            self._api_domain, self._token, verify_ssl=self._verify_ssl
+        )
         return self._token
